@@ -8,6 +8,7 @@ from .util import containYear, hasSignature
 from .get_soup import getSoup
 from .douban import getDoubanLinks
 from .vocus import getVocusLinks
+from .douban_notes import getDoubanNotes
 from collections import OrderedDict
 import pkg_resources
 import yaml
@@ -31,7 +32,7 @@ def yieldLinks(soup):
 	for item in soup.find_all('div'):
 		yield item.get('data-link')
 
-def formatRawLink(link, domain):
+def formatRawLink(link, domain, site):
 	if domain.startswith('cn.'):
 		domain = domain[3:]
 	if not link:
@@ -43,7 +44,7 @@ def formatRawLink(link, domain):
 		return
 	parts = set(link.split('/'))
 	for key, sub_config in config.items():
-		if key in domain:
+		if key in site:
 			must_contain_part = sub_config.get('must_contain_part')
 			if must_contain_part and must_contain_part not in parts:
 				return
@@ -98,16 +99,20 @@ def populateDomain(link, site):
 def getLinks(site):
 	if 'vocus.cc' in site:
 		return getVocusLinks(site)
+	if 'douban.' in site and '/notes' in site:
+		return list(getDoubanNotes(site.split('/')[4]))
 	soup = getSoup(site)
 	links = list(yieldLinks(soup))
-	links = [formatRawLink(link, site.split('/')[2]) for link in links]
+	links = [formatRawLink(link, site.split('/')[2], site) for link in links]
 	# dedup, keep order
 	links = [link for link in OrderedDict.fromkeys(links) if link]
 	if '.douban.' in site:
-		return getDoubanLinks(site, links, soup)
+		return list(getDoubanLinks(site, links, soup))
 	prefered_sig = getPreferedSig(links, site)
 	links = [populateDomain(link, site) for 
 		link in links if sigMatch(prefered_sig, getSig(link))]
 	if 'cn.nytimes.com/opinion' in site:
 		return links[:3]
+	if 'gonghao51' in site:
+		return links[:30] 
 	return links
\ No newline at end of file
